Enum Class EncryptionConfig.Scheme

java.lang.Object
java.lang.Enum<EncryptionConfig.Scheme>
com.mastercard.developer.encryption.EncryptionConfig.Scheme
All Implemented Interfaces:
Serializable, Comparable<EncryptionConfig.Scheme>, java.lang.constant.Constable
Enclosing class:
EncryptionConfig

public static enum EncryptionConfig.Scheme extends Enum<EncryptionConfig.Scheme>
The different methods of encryption
  • Enum Constant Details

  • Method Details

    • values

      public static EncryptionConfig.Scheme[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static EncryptionConfig.Scheme valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null