Package com.mastercard.developer.json
Class JsonEngine
java.lang.Object
com.mastercard.developer.json.JsonEngine
- Direct Known Subclasses:
GsonJsonEngine,JacksonJsonEngine,JettisonJsonEngine,JsonOrgJsonEngine,JsonSmartJsonEngine
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidaddProperty(Object obj, String key, Object val) protected static ObjectasPrimitiveValue(String string) static JsonEnginestatic StringgetJsonElementKey(String jsonPathString) Get object key at the given JSON path.abstract com.jayway.jsonpath.spi.json.JsonProviderstatic StringgetParentJsonPath(String jsonPathString) Get JSON path to the parent of the object at the given JSON path.getPropertyKeys(Object jsonElement) booleanisJsonObject(Object jsonElement) protected booleanisJsonPrimitive(Object jsonElement) booleanisNullOrEmptyJson(Object jsonElement) abstract ObjecttoJsonString(Object object)
-
Constructor Details
-
JsonEngine
public JsonEngine()
-
-
Method Details
-
getJsonProvider
public abstract com.jayway.jsonpath.spi.json.JsonProvider getJsonProvider() -
parse
-
getDefault
-
addProperty
-
asPrimitiveValue
-
toJsonString
-
isJsonPrimitive
-
isJsonObject
-
isNullOrEmptyJson
-
getPropertyKeys
-
getParentJsonPath
Get JSON path to the parent of the object at the given JSON path. -
getJsonElementKey
Get object key at the given JSON path.
-